
// File: Appdemo.cpp
// A Win32 API example how to use REPCODER.DLL

// We include REPCODER.H and add REPCODER.C to our project.
// REPCODER.C defines repcoder_load() that calls LoadLibraryW(L"REPCODER.DLL")
// and repcoder_free() that calls FreeLibrary().

// Written by Mariusz Nogala, Poznan, POLAND 2014
// Copyright (C), Mariusz Nogala. All rights reserved.

#define STRICT
#include <windows.h>

#include "repcoder.h" // declarations of REPCODER.DLL exported functions. REPCODER.C must be added to the project !!!

#define szAppName L"REPCoder - Sample application"
//---------------------------------------------------------------------------

static HINSTANCE  _hInst = 0;
static wchar_t    _ReportsDir[1024] = L"";
//---------------------------------------------------------------------------

void Button_1(HWND hDlg)
{
BOOL bDesign = IsDlgButtonChecked(hDlg, 91);
BOOL bResultOnly = 0;

BOOL bModal = 1;
repc_explorer(hDlg, bModal, _ReportsDir, bDesign, bResultOnly);
}
//---------------------------------------------------------------------------

void Button_2(HWND hDlg)
{
// Get the report's parameter: Month number
wchar_t monthbuf[32] = L"";
GetDlgItemTextW(hDlg, 202, monthbuf, 32);
int month = _wtoi(monthbuf);
if( month < 1 || month > 12 )
  {
   MessageBoxW(hDlg, L"The parameter is missing: Month number ...", szAppName, MB_OK|MB_ICONEXCLAMATION);
   SetFocus(GetDlgItem(hDlg, 202));
   return;
  }

// Get the report's parameter: Surname
wchar_t namebuf[64] = L"";
GetDlgItemTextW(hDlg, 203, namebuf, 64);
if( *namebuf == 0 )
  {
   MessageBoxW(hDlg, L"The parameter is missing: Surname ...", szAppName, MB_OK|MB_ICONEXCLAMATION);
   SetFocus(GetDlgItem(hDlg, 203));
   return;
  }

// some arguments to call the function: repc_open_report
BOOL bModal = IsDlgButtonChecked(hDlg, 81);
BOOL bParamsUpdate = IsDlgButtonChecked(hDlg, 82);
BOOL bAllowDesign = IsDlgButtonChecked(hDlg, 83);
BOOL bDesignMode = IsDlgButtonChecked(hDlg, 84);

if( bDesignMode && !bAllowDesign )
  {
   MessageBoxW(hDlg, L"\"bDesignMode\" cannot work without \"bAllowDesign\" ...", szAppName, MB_OK|MB_ICONEXCLAMATION);
   SetFocus(GetDlgItem(hDlg, 84));
   return;
  }

//----- parameters of the report
int nParams = 2;
int pParamsNumbers[2] = { 1, 3 };
wchar_t* pParamsValues[2];
pParamsValues[0] = monthbuf;
pParamsValues[1] = namebuf;

//----- report's project filename
wchar_t fname[256];
wsprintfW(fname, L"%s/Report_14 - parameters.sfm", _ReportsDir);

//----- call the basic function of REPCODER.DLL
repc_open_report(hDlg, bModal, fname, 0,
nParams, pParamsNumbers, pParamsValues,
bParamsUpdate, 1, bDesignMode, bAllowDesign, 0);
}
//---------------------------------------------------------------------------

BOOL CALLBACK MainDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM /*lParam*/)
{
switch (uMsg)
  {
   case WM_INITDIALOG:
   SendMessage(hDlg, WM_SETICON, 1, (LPARAM)LoadIconW(_hInst, L"SNAKE"));

   GetCurrentDirectoryW(1024, _ReportsDir);
   wcscat(_ReportsDir, L"\\Samples");

   CheckDlgButton(hDlg, 81, 1);
   CheckDlgButton(hDlg, 82, 1);
   CheckDlgButton(hDlg, 83, 1);
   SetDlgItemTextW(hDlg, 202, L"4");
   SetDlgItemTextW(hDlg, 203, L"Norman");
   break;

   case WM_COMMAND:
   switch ( LOWORD(wParam) )
     {
      case IDCANCEL:
        int n;
        n = repc_get_open_count();
        if( n > 0 )
          {
           wchar_t buf[100];
           wsprintfW(buf, L"The number of open report windows = %d\nExit the program ?", n);
           int ret = MessageBoxW(hDlg, buf, szAppName, MB_YESNO|MB_ICONQUESTION);
           if( ret != IDYES ) break;
          }
        else
          {
           int ret = MessageBoxW(hDlg, L"Exit the program ?", szAppName, MB_YESNO|MB_ICONQUESTION);
           if( ret != IDYES ) break;
          }

        EndDialog(hDlg, IDCANCEL);
      break;

      case 90:
        repc_set_demo( IsDlgButtonChecked(hDlg, 90) );
        break;

      case 101:
        Button_1(hDlg);
        break;

      case 102:
        Button_2(hDlg);
        break;

      default: break;
     }
   break;

   default: return 0;
  }

return 1;
}
//---------------------------------------------------------------------------

int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE, LPSTR, int)
{
_hInst = hInstance;

if( !repcoder_load() ) return 0; // Load REPCODER.DLL

BOOL ok = repc_init();
if( !ok ) return 0;

DialogBoxW(hInstance, L"MAIN_DLG", 0, MainDlgProc);

repc_exit();

repcoder_free(); // Free REPCODER.DLL
return 0;
}

